@@ -1,7 +1,13 @@
 use strict;
 use warnings;
 package Math::HexGrid::Hex;
-$Math::HexGrid::Hex::VERSION = '0.02';
+$Math::HexGrid::Hex::VERSION = '0.03';
+use overload
+  '""' => 'to_string',
+  fallback => 1;
+
+sub to_string { $_[0]->{id} }
+
 
 sub new
 {
@@ -14,10 +20,13 @@ sub new
     unless defined $q && defined $r && defined $s
       && $q + $r + $s == 0;
 
-  bless { q => $q, r => $r, s => $s }, $class;
+  bless { q => $q, r => $r, s => $s, id => "$q,$r" }, $class;
 }
 
 
+sub id { $_[0]->{id} }
+
+
 sub hex_equal
 {
   my ($self, $hex) = @_;
@@ -28,6 +37,9 @@ sub hex_equal
 }
 
 
+sub is_colliding { $_[0]->hex_equal($_[1]) }
+
+
 sub hex_add
 {
   my ($self, $hex) = @_;
@@ -109,7 +121,7 @@ Math::HexGrid::Hex
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -133,12 +145,20 @@ Math::HexGrid::Hex - a hex class for use with hex grids
 
 =head2 new ($q, $r, $s)
 
-Creates a new Hex object.
+Creates a new Hex object, the C<$s> integer is optional.
+
+=head2 id
+
+Returns a comma-separated string of the Hex's q and r coordinates.
 
 =head2 hex_equal ($hex)
 
 Compare two Hex objects for equality
 
+=head2 is_colliding ($hex)
+
+Same as C<hex_equal>.
+
 =head2 hex_add($hex)
 
 Adds another Hex to the object and returns a new Hex object.
